__author__ = "navid nasiri"
__github__ = "https://github.com/goldaaa"
__gmail__ = "goldaaa.program@gmail.com"

__all__ = ('Config', 'ConfigBase', 'IrLabel', 'IrTextInput')

from .ConfigBase import *
from .IrLabel import *
from .IrTextInput import *
